/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.keyword.apio.internal.permission;

import com.liferay.apio.architect.alias.routes.permission.HasNestedAddingPermissionFunction;
import com.liferay.apio.architect.credentials.Credentials;
import com.liferay.apio.architect.identifier.Identifier;
import com.liferay.asset.kernel.model.AssetTag;
import com.liferay.asset.kernel.service.AssetTagService;
import com.liferay.portal.apio.permission.HasPermission;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.security.permission.ActionKeys;
import com.liferay.portal.kernel.security.permission.PermissionChecker;
import com.liferay.portlet.asset.service.permission.AssetTagsPermission;
import com.liferay.site.apio.architect.identifier.WebSiteIdentifier;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Eduardo Perez
 */
@Component(
	immediate = true,
	property = "model.class.name=com.liferay.asset.kernel.model.AssetTag"
)
public class KeywordHasPermissionImpl implements HasPermission<Long> {

	@Override
	public <S> HasNestedAddingPermissionFunction<S> forAddingIn(
		Class<? extends Identifier<S>> identifierClass) {

		if (identifierClass.equals(WebSiteIdentifier.class)) {
			return (credentials, groupId) -> {
				return AssetTagsPermission.contains(
					(PermissionChecker)credentials.get(), (Long)groupId,
					ActionKeys.MANAGE_TAG);
			};
		}

		return (credentials, s) -> false;
	}

	@Override
	public Boolean forDeleting(Credentials credentials, Long assetTagId)
		throws PortalException {

		AssetTag assetTag = _assetTagService.getTag(assetTagId);

		return AssetTagsPermission.contains(
			(PermissionChecker)credentials.get(), assetTag.getGroupId(),
			ActionKeys.MANAGE_TAG);
	}

	@Override
	public Boolean forUpdating(Credentials credentials, Long assetTagId)
		throws PortalException {

		AssetTag assetTag = _assetTagService.getTag(assetTagId);

		return AssetTagsPermission.contains(
			(PermissionChecker)credentials.get(), assetTag.getGroupId(),
			ActionKeys.MANAGE_TAG);
	}

	@Reference
	private AssetTagService _assetTagService;

}